#!/bin/sh
# $Id: 2_basesystem.sh 23 2016-08-01 20:54:03Z dettus $

echo "
       -----         -----         
      /     \\       /     \\       /
     /       \\     /       \\     /
-----         -----         -----
     \\       /     \\       /     \\
      \\     /       \\     /       \\
       -----         ----- detLFS  -
      /     \\       /     \\       /
     /       \\     /       \\     /
-----         -----         -----
http://www.dettus.net/detLFS/detLFS_0.04.gar.gz

 The purpose of this script is to build the linux Kernel and Busybox.
 It will also copy the init-scripts and the bootloader into the Destination
 directory. The configuration part could be performed with menuconfig, for
 the purpose of minimalism, this script is copying a generic configuration.

 Hopefully, the previous scripts are finished at this point.
" ; date





export DETLFSROOT=`pwd`
export TOOLSDIR=`pwd`/Tools
export BUILDDIR=`pwd`/Build
export SOURCESDIR=`pwd`/Sources
export DOWNLOADSDIR=`pwd`/Downloads
export DESTINATIONDIR=`pwd`/Destination

mkdir -p $DESTINATIONDIR

export PATH=$TOOLSDIR/bin:$PATH

echo ">>> building KERNEL (raspberry pi specific)" ; date
(
	cd $BUILDDIR/
	rm -rf linux ; cp -r $SOURCESDIR/linux .
	cd linux
	export KERNEL=kernel7
	convert $DETLFSROOT/logo/mylogo.xpm -scale \!80x80 /tmp/mylogo.png
	pngtopnm /tmp/mylogo.png | ppmquant 224 | pnmnoraw >drivers/video/logo/logo_linux_clut224.ppm
	make ARCH=arm CROSS_COMPILE=$TOOLSDIR/bin/arm-linux-gnueabihf- bcm2709_defconfig
## configuration of the kernel can be done by choosing one of the three. 
	cat $DETLFSROOT/config_kernel | sed -e 's?CONFIG_CROSS_COMPILE=".*"?CONFIG_CROSS_COMPILE="'$TOOLSDIR'/bin/arm-linux-gnueabihf-"?g' >.config 
#	vimdiff .config $DETLFSROOT/config_kernel
#	make ARCH=arm menuconfig
### pick one!
	make ARCH=arm CROSS_COMPILE=$TOOLSDIR/bin/arm-linux-gnueabihf- zImage modules dtbs -j 8
	mkdir -p $DESTINATIONDIR/boot $DESTINATIONDIR/usr
	make ARCH=arm CROSS_COMPILE=$TOOLSDIR/bin/arm-linux-gnueabihf- INSTALL_MOD_PATH=$DESTINATIONDIR/ INSTALL_HDR_PATH=$DESTINATIONDIR/usr/ modules_install headers_install
	cp arch/arm/boot/zImage $DESTINATIONDIR/boot/kernel.img
	cp arch/arm/boot/dts/*.dtb $DESTINATIONDIR/boot
	mkdir -p $DESTINATIONDIR/boot/overlays
	cp arch/arm/boot/dts/overlays/*.dtb $DESTINATIONDIR/boot/overlays
	cp arch/arm/boot/dts/overlays/README $DESTINATIONDIR/boot/overlays
)

echo ">>> building BUSYBOX" ; date
(
	cd $BUILDDIR/
	rm -rf busybox ; cp -r $SOURCESDIR/busybox . ; cd busybox
   	make ARCH=arm CROSS_COMPILE=$TOOLSDIR/bin/arm-linux-gnueabihf- defconfig
## configuration of the kernel can be done by choosing one of the three. 
	cat $DETLFSROOT/config_busybox | sed -e 's?CONFIG_CROSS_COMPILER_PREFIX=".*"?CONFIG_CROSS_COMPILER_PREFIX="'$TOOLSDIR'/bin/arm-linux-gnueabihf-"?g' >.config
# 	vimdiff .config ../../../config_busybox
#   	make ARCH=arm menuconfig
### pick one!
   	make ARCH=arm CROSS_COMPILE=$TOOLSDIR/bin/arm-linux-gnueabihf- install -j 8
	cd _install
	pwd
	tar cvf - * | ( cd $DESTINATIONDIR ; tar xvf - )
	date
)



echo ">>> copying skeldir/" ; date
(
	cd $DETLFSROOT/skeldir
	pwd
	tar cvf - * | ( cd $DESTINATIONDIR ; tar xvf - )
)
echo ">>> copying raspberry specific bootloader files" ; date
(
	cp $DOWNLOADSDIR/start.elf $DOWNLOADSDIR/bootcode.bin $DESTINATIONDIR/boot/
)

du -sh $DESTINATIONDIR
echo ">>>> done" ; date
